<?php
/**
 * Functions that output contents
 * 
 * @package	xincore
 * @since   1.0
 * @author  XinThemes
 * @license GPL v3 or later
 * @link    http://www.xinthemes.com/
 */
//Section Menu
if ( ! function_exists( 'xinwp_section_menu' ) ):
function xinwp_section_menu( $id = 'section-menu', $search = false ) {
	if ( has_nav_menu( 'section' ) ) {
		echo '<nav id="' . $id. '" class="section-menu clearfix">';
		wp_nav_menu( array(
			'theme_location'  => 'section',
			'container'       => false,
			'fallback_cb'     => false,
		));
		if ( $search )
			get_search_form();
		echo '</nav>';
	}
}
endif;

if ( ! function_exists( 'xinwp_single_post_link' ) ) :
/* This function echo the link to single post view for the following:
- Aside Post
- Post without title
------------------------------------------------------------------------- */
function xinwp_single_post_link() {
	if ( ! is_single() ) {
		if ( has_post_format( 'aside' ) || has_post_format( 'quote' ) || '' == the_title_attribute( 'echo=0' ) ) { 
			printf ('<a class="single-post-link" href="%1$s" title="%1$s"><i class="icon-chevron-right"></i></a>',
				get_permalink(),
				get_the_title()	);
		} 
	}
}
endif;

if ( ! function_exists( 'xinwp_template_intro' ) ) :
function xinwp_template_intro() {
//	global $post;
	if ( ! is_page() )
		return;
	$content = get_the_content();
	$content = apply_filters( 'the_content', $content );
	$content = str_replace( ']]>', ']]&gt;', $content );
	if ( ! empty($content)) {
?>
<article id="post-<?php the_ID(); ?>" class="template-intro clearfix <?php echo xinwp_grid_full(); ?>">
<?php
		echo '<div class="entry-content clearfix">';
		echo $content;
		echo '</div>';			
?>
</article>
<?php
	}
}
endif;

/******************************
* Pagination for main loop
******************************/
function xinwp_content_nav( $nav_id ) {
	global $wp_query;
	xinwp_content_nav_link( $wp_query->max_num_pages, $nav_id );
}

/******************************
* Pagination
******************************/
function xinwp_content_nav_link( $num_of_pages, $nav_id ) {
	$html = '';
	if ( $num_of_pages > 1 ) {
		$html .= '<nav id="' . $nav_id . '" class="pagination-centered">';
		$html .=  '<ul class="pagination">';

		$big = 999999999;
    	if ( get_query_var( 'paged' ) )
	    	$current_page = get_query_var( 'paged' );
		elseif ( get_query_var( 'page' ) ) 
	   	 	$current_page = get_query_var( 'page' );
		else 
			$current_page = 1;
		$links =  paginate_links( array(
			'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'format' => '?paged=%#%',
			'current' => max( 1, $current_page ),
			'total' => $num_of_pages,
			'mid_size' => 3,
			'prev_text'    => '<i class="icon-chevron-left"></i>' ,
			'next_text'    => '<i class="icon-chevron-right"></i>' ,
			'type' => 'array' ) );
			
		$html .=  '<li><span>' . __( 'Page ', 'winwp' ) . '</span></li>';
		foreach ( $links as $link )
			$html .= '<li>' . $link . '</li>';
		$html .='</ul></nav>';
	}
	echo apply_filters( 'xinwp_pagination', $html );
}

/********************************************
* Display Post Date 
********************************************/
function xinwp_meta_date( $style = 1) {
	$html = '';
	if ( 1 == $style ) {
		$html .= '<p class="post-date-2">';
		$html .=  '<span class="month">' . get_the_date('M') . '</span>';
		$html .=  '<span class="day">' . get_the_date('j') . '</span>';
		$html .=  '<span class="year">' . get_the_date('Y') . '</span></p>';
	} elseif ( 2 == $style ) {
		$html .=  '<i class="icon-calendar meta-icon"> </i>';
		$html .= sprintf( __( '<time class="entry-date" datetime="%1$s">%2$s</time>', 'xinwp' ),
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ) );				
	}
	echo apply_filters( 'xinwp_meta_post_date', $html );
}

if ( ! function_exists( 'xinwp_meta_category' ) ) :
// Prints Post Categories
function xinwp_meta_category() {
	$categories = wp_get_post_categories( get_the_ID() , array('fields' => 'ids'));
	if( $categories ) {
 		$sep = ' &bull; ';
 		$cat_ids = implode( ',' , $categories );
 		$cats = wp_list_categories( 'title_li=&style=none&echo=0&include='.$cat_ids);
 		$cats = rtrim( trim( str_replace( '<br />',  $sep, $cats) ), $sep);
		echo '<span class="entry-category">';
		echo '<span class="meta-prep"><i class="icon-folder-open meta-icon"> </i></span>';	
 		echo  $cats;
		echo '</span>';
	}
}
endif;

function xinwp_meta_author() {
	$html = sprintf( '<span class="by-author"><a class="url fn n" href="%1$s" title="%2$s" rel="author"><span class="meta-prep">%4$s</span> %3$s</a></span>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'xinwp' ), get_the_author() ) ),
		get_the_author(),
		'<i class="icon-user meta-icon"> </i>' );
	echo apply_filters( 'xinwp_meta_author', $html );
}

if ( ! function_exists( 'xinwp_meta_comment' ) ) :
// Prints Comments Link
function xinwp_meta_comment() {
	if ( comments_open() && ! post_password_required() ) {
		$comment_icon = '<i class="icon-comments meta-icon"></i> ';
		printf( '<span class="meta-comment">' );
		comments_popup_link( $comment_icon . __( 'Comment', 'xinwp' ), $comment_icon . __( '1 Comment', 'xinwp' ) , $comment_icon . __( '% Comments', 'xinwp' ) );		
		printf( '</span>' );
	}
}
endif;

if ( ! function_exists( 'xinwp_meta_tag' ) ) :
// Prints Post Tags
function xinwp_meta_tag() {
	$tags_list = get_the_tag_list( '', __( ' &bull; ', 'xinwp' ) );
	if ( $tags_list ) {
		echo '<span class="entry-tags"><i class="icon-tags meta-icon"> </i>';
		printf( '<span class="entry-tag">%1$s</span>',
		$tags_list );
		echo '</span>';
	} 
}
endif;

if ( ! function_exists( 'xinwp_post_meta' ) ) :
function xinwp_post_meta() {
	if ( 'post' == get_post_type() ) {
		echo '<span class="entry-meta">';		
		if ( is_sticky() ) {
			printf( '<span class="entry-featured">%1$s </span>', __( 'Featured ', 'xinwp') );
		}
		xinwp_meta_author();
		xinwp_meta_category();
		xinwp_meta_comment();			
		echo '</span>';	
	}
}
endif;

if ( ! function_exists( 'xinwp_meta_bottom' ) ) :
// Prints tags, edit link at the bottom of the post
function xinwp_meta_bottom() {
	printf ('<div class="entry-meta entry-meta-bottom">');	
	if ( 'post' == get_post_type() ) {
		if ( ! is_single() ) {
			printf ('<span class="entry-more"><a href="%1$s" title="%2$s"><i class="icon-hand-right"></i> %3$s</span></a>',
				get_permalink(),
				get_the_title(),
				__( 'Read More', 'xinwp') );	
		}		
		xinwp_meta_tag();	
	}
	edit_post_link( '<i class="icon-pencil"></i> ' . __( '[Edit]', 'xinwp' ), '<span class="edit-link">', '</span>' );
	echo '</div>';	
}
endif;

if ( ! function_exists( 'xinwp_post_summary_meta' ) ) :
// Prints meta info for Post Summary
function xinwp_post_summary_meta( $meta_flag = 0 ) {
	global $xinwp_entry_meta;
	
	echo '<div class="entry-meta entry-meta-summary clearfix">';
	if ( ( $xinwp_entry_meta || $meta_flag ) && 'post' == get_post_type() ) {
		xinwp_meta_date( 2 );
		xinwp_meta_author();
		xinwp_meta_category();
		xinwp_meta_tag();
		xinwp_meta_comment();
	}
	edit_post_link( '<i class="icon-pencil"></i> ' . __( '[Edit]', 'xinwp' ), '<span class="edit-link">', '</span>' );	
	echo '</div>';	
}
endif;

if ( ! function_exists( 'xinwp_author_info' ) ) :
/************************************************
Display Author Info on single post view 
 and author has filled out their description
 and showauthor option checked 
************************************************/ 
function xinwp_author_info() {
	if ( is_single() && get_the_author_meta( 'description' )  ) { ?>
	<div id="author-info">
		<div id="author-avatar">
			<?php echo get_avatar( get_the_author_meta( 'user_email' ), apply_filters( 'xinwp_author_bio_avatar_size', 64 ) ); ?>
		</div><!-- #author-avatar -->
		<div id="author-description">
			<h2><?php printf( __( 'About %s', 'xinwp' ), get_the_author() ); ?></h2>
			<p><?php the_author_meta( 'description' ); ?></p>
			<div id="author-link">
				<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author"><?php printf( __( 'View all posts by %s <span class="meta-nav"></span>', 'xinwp' ), get_the_author() ); ?></a>
			</div>
		</div>
	</div>
<?php 
	}
}
endif;

if ( ! function_exists( 'xinwp_post_title' ) ) :
// Display Post Title
function xinwp_post_title() {
	global $xinwp_layout;
	if ( ! is_single()  ) {
		printf('<h2 class="entry-title"><a href="%1$s" title="%2$s" rel="bookmark">%3$s</a></h2>',
			get_permalink(),
			sprintf( esc_attr__( 'Permalink to %s', 'xinwp' ), the_title_attribute( 'echo=0' ) ),
			get_the_title()	);
	}
	else {
		printf('<h1 class="entry-title">%1$s</h1>',
			get_the_title()	);		
	}
}
endif;

/******************************
* Display Featured Image
******************************/
if ( ! function_exists( 'xinwp_post_thumbnail' ) ) :
function xinwp_post_thumbnail( $post_id ) {
	global $xinwp_layout;
	if ( has_post_thumbnail() ) {
		if ( ! is_single() ) {
			printf ('<a href="%1$s" title="%2$s">', 
				get_permalink(),
				get_the_title()	);	
			the_post_thumbnail( 'large', array( 'class'	=> 'img-polaroid featured-image', 'title' => get_the_title() ) );
			echo '</a>';
		}
		else {
			if ( 2 == $xinwp_layout )			
				the_post_thumbnail( 'full', array( 'class'	=> 'fullscreen-image' ) );	
			else
				the_post_thumbnail( 'large', array( 'class'	=> 'img-polaroid featured-image', 'title' => get_the_title() ) );	
		}
	}
}
endif;
